==> antd-mobile-1.0.7.tgz: package/lib/accordion/demo/basic.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _accordion=require('antd-mobile/components/accordion');var _accordion2=_interopRequireDefault(_accordion);var _list=require('antd-mobile/components/list');var _list2=_interopRequireDefault(_list);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);
var _react=require('react');var _react2=_interopRequireDefault(_react);
var _reactNative=require('react-native');function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}var

AccordionExmple=function(_React$Component){(0,_inherits3["default"])(AccordionExmple,_React$Component);
function AccordionExmple(){(0,_classCallCheck3["default"])(this,AccordionExmple);var _this=(0,_possibleConstructorReturn3["default"])(this,
_React$Component.apply(this,arguments));
_this.onChange=function(key){
console.log(key);
};return _this;
}AccordionExmple.prototype.
render=function render(){
return _react2["default"].createElement(_reactNative.View,{style:{marginTop:80,marginBottom:10}},
_react2["default"].createElement(_accordion2["default"],{onChange:this.onChange,defaultActiveKey:'2'},
_react2["default"].createElement(_accordion2["default"].Panel,{key:'1',header:'\u6807\u9898\u4E00'},
_react2["default"].createElement(_list2["default"],null,
_react2["default"].createElement(_list2["default"].Item,null,'\u5B50\u5185\u5BB9\u4E00'),
_react2["default"].createElement(_list2["default"].Item,null,'\u5B50\u5185\u5BB9\u4E8C'),
_react2["default"].createElement(_list2["default"].Item,null,'\u5B50\u5185\u5BB9\u4E09'))),


_react2["default"].createElement(_accordion2["default"].Panel,{key:'2',header:'\u6807\u9898\u4E8C'},'this is panel content2 or other'),
_react2["default"].createElement(_accordion2["default"].Panel,{key:'3',header:'\u6807\u9898\u4E09'},'\u6587\u672C\u5185\u5BB9\u6587\u672C\u5185\u5BB9\u6587\u672C\u5185\u5BB9\u6587\u672C\u5185\u5BB9\u6587\u672C\u5185\u5BB9\u6587\u672C\u5185\u5BB9\u6587\u672C\u5185\u5BB9\u6587\u672C\u5185\u5BB9\u6587\u672C\u5185\u5BB9\u6587\u672C\u5185\u5BB9\u6587\u672C')));




};return AccordionExmple;}(_react2["default"].Component);exports["default"]=AccordionExmple;module.exports=exports['default'];

==> antd-mobile-1.1.1.tgz: package/lib/accordion/demo/basic.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _accordion=require('antd-mobile/components/accordion');var _accordion2=_interopRequireDefault(_accordion);var _list=require('antd-mobile/components/list');var _list2=_interopRequireDefault(_list);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);
var _react=require('react');var _react2=_interopRequireDefault(_react);
var _reactNative=require('react-native');function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}var

AccordionExmple=function(_React$Component){(0,_inherits3["default"])(AccordionExmple,_React$Component);
function AccordionExmple(){(0,_classCallCheck3["default"])(this,AccordionExmple);var _this=(0,_possibleConstructorReturn3["default"])(this,
_React$Component.apply(this,arguments));
_this.onChange=function(key){
console.log(key);
};return _this;
}AccordionExmple.prototype.
render=function render(){
return _react2["default"].createElement(_reactNative.View,{style:{marginTop:80,marginBottom:10}},
_react2["default"].createElement(_accordion2["default"],{onChange:this.onChange,defaultActiveKey:'2'},
_react2["default"].createElement(_accordion2["default"].Panel,{header:'Title 1'},
_react2["default"].createElement(_list2["default"],null,
_react2["default"].createElement(_list2["default"].Item,null,'Content 1'),
_react2["default"].createElement(_list2["default"].Item,null,'Content 2'),
_react2["default"].createElement(_list2["default"].Item,null,'Content 3'))),


_react2["default"].createElement(_accordion2["default"].Panel,{header:'Title 2'},'this is panel content2 or other'),
_react2["default"].createElement(_accordion2["default"].Panel,{header:'Title 3'},'Text text text text text text text text text text text text text text text')));




};return AccordionExmple;}(_react2["default"].Component);exports["default"]=AccordionExmple;module.exports=exports['default'];
